Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBypassServer(s grpc.ServiceRegistrar, srv BypassServer)
- func RegisterConfigServiceServer(s grpc.ServiceRegistrar, srv ConfigServiceServer)
- func RegisterInboundServer(s grpc.ServiceRegistrar, srv InboundServer)
- func RegisterResolverServer(s grpc.ServiceRegistrar, srv ResolverServer)
- type BlockHistory
- func (x *BlockHistory) ClearBlockCount()
- func (x *BlockHistory) ClearHost()
- func (x *BlockHistory) ClearProcess()
- func (x *BlockHistory) ClearProtocol()
- func (x *BlockHistory) ClearTime()
- func (x *BlockHistory) GetBlockCount() uint64
- func (x *BlockHistory) GetHost() string
- func (x *BlockHistory) GetProcess() string
- func (x *BlockHistory) GetProtocol() string
- func (x *BlockHistory) GetTime() *timestamppb.Timestamp
- func (x *BlockHistory) HasBlockCount() bool
- func (x *BlockHistory) HasHost() bool
- func (x *BlockHistory) HasProcess() bool
- func (x *BlockHistory) HasProtocol() bool
- func (x *BlockHistory) HasTime() bool
- func (*BlockHistory) ProtoMessage()
- func (x *BlockHistory) ProtoReflect() protoreflect.Message
- func (x *BlockHistory) Reset()
- func (x *BlockHistory) SetBlockCount(v uint64)
- func (x *BlockHistory) SetHost(v string)
- func (x *BlockHistory) SetProcess(v string)
- func (x *BlockHistory) SetProtocol(v string)
- func (x *BlockHistory) SetTime(v *timestamppb.Timestamp)
- func (x *BlockHistory) String() string
- type BlockHistoryList
- func (x *BlockHistoryList) ClearDumpProcessEnabled()
- func (x *BlockHistoryList) GetDumpProcessEnabled() bool
- func (x *BlockHistoryList) GetObjects() []*BlockHistory
- func (x *BlockHistoryList) HasDumpProcessEnabled() bool
- func (*BlockHistoryList) ProtoMessage()
- func (x *BlockHistoryList) ProtoReflect() protoreflect.Message
- func (x *BlockHistoryList) Reset()
- func (x *BlockHistoryList) SetDumpProcessEnabled(v bool)
- func (x *BlockHistoryList) SetObjects(v []*BlockHistory)
- func (x *BlockHistoryList) String() string
- type BlockHistoryList_builder
- type BlockHistory_builder
- type BypassClient
- type BypassServer
- type ConfigServiceClient
- type ConfigServiceServer
- type Hosts
- type Hosts_builder
- type InboundClient
- type InboundServer
- type InboundsResponse
- type InboundsResponse_builder
- type ResolveList
- type ResolveList_builder
- type ResolverClient
- type ResolverServer
- type SaveResolver
- func (x *SaveResolver) ClearName()
- func (x *SaveResolver) ClearResolver()
- func (x *SaveResolver) GetName() string
- func (x *SaveResolver) GetResolver() *dns.Dns
- func (x *SaveResolver) HasName() bool
- func (x *SaveResolver) HasResolver() bool
- func (*SaveResolver) ProtoMessage()
- func (x *SaveResolver) ProtoReflect() protoreflect.Message
- func (x *SaveResolver) Reset()
- func (x *SaveResolver) SetName(v string)
- func (x *SaveResolver) SetResolver(v *dns.Dns)
- func (x *SaveResolver) String() string
- type SaveResolver_builder
- type TestResponse
- func (x *TestResponse) ClearAfterAddr()
- func (x *TestResponse) ClearMode()
- func (x *TestResponse) ClearReason()
- func (x *TestResponse) GetAfterAddr() string
- func (x *TestResponse) GetMode() *bypass.ModeConfig
- func (x *TestResponse) GetReason() string
- func (x *TestResponse) HasAfterAddr() bool
- func (x *TestResponse) HasMode() bool
- func (x *TestResponse) HasReason() bool
- func (*TestResponse) ProtoMessage()
- func (x *TestResponse) ProtoReflect() protoreflect.Message
- func (x *TestResponse) Reset()
- func (x *TestResponse) SetAfterAddr(v string)
- func (x *TestResponse) SetMode(v *bypass.ModeConfig)
- func (x *TestResponse) SetReason(v string)
- func (x *TestResponse) String() string
- type TestResponse_builder
- type UnimplementedBypassServer
- func (UnimplementedBypassServer) BlockHistory(context.Context, *emptypb.Empty) (*BlockHistoryList, error)
- func (UnimplementedBypassServer) Load(context.Context, *emptypb.Empty) (*bypass.Config, error)
- func (UnimplementedBypassServer) Reload(context.Context, *emptypb.Empty) (*emptypb.Empty, error)
- func (UnimplementedBypassServer) Save(context.Context, *bypass.Config) (*emptypb.Empty, error)
- func (UnimplementedBypassServer) Test(context.Context, *wrapperspb.StringValue) (*TestResponse, error)
- type UnimplementedConfigServiceServer
- func (UnimplementedConfigServiceServer) Info(context.Context, *emptypb.Empty) (*config.Info, error)
- func (UnimplementedConfigServiceServer) Load(context.Context, *emptypb.Empty) (*config.Setting, error)
- func (UnimplementedConfigServiceServer) Save(context.Context, *config.Setting) (*emptypb.Empty, error)
- type UnimplementedInboundServer
- func (UnimplementedInboundServer) Get(context.Context, *wrapperspb.StringValue) (*listener.Inbound, error)
- func (UnimplementedInboundServer) List(context.Context, *emptypb.Empty) (*InboundsResponse, error)
- func (UnimplementedInboundServer) Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
- func (UnimplementedInboundServer) Save(context.Context, *listener.Inbound) (*listener.Inbound, error)
- type UnimplementedResolverServer
- func (UnimplementedResolverServer) Fakedns(context.Context, *emptypb.Empty) (*dns.FakednsConfig, error)
- func (UnimplementedResolverServer) Get(context.Context, *wrapperspb.StringValue) (*dns.Dns, error)
- func (UnimplementedResolverServer) Hosts(context.Context, *emptypb.Empty) (*Hosts, error)
- func (UnimplementedResolverServer) List(context.Context, *emptypb.Empty) (*ResolveList, error)
- func (UnimplementedResolverServer) Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
- func (UnimplementedResolverServer) Save(context.Context, *SaveResolver) (*dns.Dns, error)
- func (UnimplementedResolverServer) SaveFakedns(context.Context, *dns.FakednsConfig) (*emptypb.Empty, error)
- func (UnimplementedResolverServer) SaveHosts(context.Context, *Hosts) (*emptypb.Empty, error)
- type UnsafeBypassServer
- type UnsafeConfigServiceServer
- type UnsafeInboundServer
- type UnsafeResolverServer
Constants ¶
const ( ConfigService_Load_FullMethodName = "/yuhaiin.protos.config.service.config_service/load" ConfigService_Save_FullMethodName = "/yuhaiin.protos.config.service.config_service/save" ConfigService_Info_FullMethodName = "/yuhaiin.protos.config.service.config_service/info" )
const ( Bypass_Load_FullMethodName = "/yuhaiin.protos.config.service.bypass/load" Bypass_Save_FullMethodName = "/yuhaiin.protos.config.service.bypass/save" Bypass_Reload_FullMethodName = "/yuhaiin.protos.config.service.bypass/reload" Bypass_Test_FullMethodName = "/yuhaiin.protos.config.service.bypass/test" Bypass_BlockHistory_FullMethodName = "/yuhaiin.protos.config.service.bypass/block_history" )
const ( Inbound_List_FullMethodName = "/yuhaiin.protos.config.service.inbound/list" Inbound_Get_FullMethodName = "/yuhaiin.protos.config.service.inbound/get" Inbound_Save_FullMethodName = "/yuhaiin.protos.config.service.inbound/save" Inbound_Remove_FullMethodName = "/yuhaiin.protos.config.service.inbound/remove" )
const ( Resolver_List_FullMethodName = "/yuhaiin.protos.config.service.resolver/list" Resolver_Get_FullMethodName = "/yuhaiin.protos.config.service.resolver/get" Resolver_Save_FullMethodName = "/yuhaiin.protos.config.service.resolver/save" Resolver_Remove_FullMethodName = "/yuhaiin.protos.config.service.resolver/remove" Resolver_Hosts_FullMethodName = "/yuhaiin.protos.config.service.resolver/hosts" Resolver_SaveHosts_FullMethodName = "/yuhaiin.protos.config.service.resolver/save_hosts" Resolver_Fakedns_FullMethodName = "/yuhaiin.protos.config.service.resolver/fakedns" Resolver_SaveFakedns_FullMethodName = "/yuhaiin.protos.config.service.resolver/save_fakedns" )
Variables ¶
var Bypass_ServiceDesc = grpc.ServiceDesc{ ServiceName: "yuhaiin.protos.config.service.bypass", HandlerType: (*BypassServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "load", Handler: _Bypass_Load_Handler, }, { MethodName: "save", Handler: _Bypass_Save_Handler, }, { MethodName: "reload", Handler: _Bypass_Reload_Handler, }, { MethodName: "test", Handler: _Bypass_Test_Handler, }, { MethodName: "block_history", Handler: _Bypass_BlockHistory_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "config/grpc/config.proto", }
Bypass_ServiceDesc is the grpc.ServiceDesc for Bypass service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ConfigService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "yuhaiin.protos.config.service.config_service", HandlerType: (*ConfigServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "load", Handler: _ConfigService_Load_Handler, }, { MethodName: "save", Handler: _ConfigService_Save_Handler, }, { MethodName: "info", Handler: _ConfigService_Info_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "config/grpc/config.proto", }
ConfigService_ServiceDesc is the grpc.ServiceDesc for ConfigService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_config_grpc_config_proto protoreflect.FileDescriptor
var Inbound_ServiceDesc = grpc.ServiceDesc{ ServiceName: "yuhaiin.protos.config.service.inbound", HandlerType: (*InboundServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "list", Handler: _Inbound_List_Handler, }, { MethodName: "get", Handler: _Inbound_Get_Handler, }, { MethodName: "save", Handler: _Inbound_Save_Handler, }, { MethodName: "remove", Handler: _Inbound_Remove_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "config/grpc/config.proto", }
Inbound_ServiceDesc is the grpc.ServiceDesc for Inbound service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var Resolver_ServiceDesc = grpc.ServiceDesc{ ServiceName: "yuhaiin.protos.config.service.resolver", HandlerType: (*ResolverServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "list", Handler: _Resolver_List_Handler, }, { MethodName: "get", Handler: _Resolver_Get_Handler, }, { MethodName: "save", Handler: _Resolver_Save_Handler, }, { MethodName: "remove", Handler: _Resolver_Remove_Handler, }, { MethodName: "hosts", Handler: _Resolver_Hosts_Handler, }, { MethodName: "save_hosts", Handler: _Resolver_SaveHosts_Handler, }, { MethodName: "fakedns", Handler: _Resolver_Fakedns_Handler, }, { MethodName: "save_fakedns", Handler: _Resolver_SaveFakedns_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "config/grpc/config.proto", }
Resolver_ServiceDesc is the grpc.ServiceDesc for Resolver service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterBypassServer ¶ added in v0.3.7
func RegisterBypassServer(s grpc.ServiceRegistrar, srv BypassServer)
func RegisterConfigServiceServer ¶
func RegisterConfigServiceServer(s grpc.ServiceRegistrar, srv ConfigServiceServer)
func RegisterInboundServer ¶ added in v0.3.8
func RegisterInboundServer(s grpc.ServiceRegistrar, srv InboundServer)
func RegisterResolverServer ¶ added in v0.3.8
func RegisterResolverServer(s grpc.ServiceRegistrar, srv ResolverServer)
Types ¶
type BlockHistory ¶ added in v0.3.7
type BlockHistory struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*BlockHistory) ClearBlockCount ¶ added in v0.3.8
func (x *BlockHistory) ClearBlockCount()
func (*BlockHistory) ClearHost ¶ added in v0.3.8
func (x *BlockHistory) ClearHost()
func (*BlockHistory) ClearProcess ¶ added in v0.3.8
func (x *BlockHistory) ClearProcess()
func (*BlockHistory) ClearProtocol ¶ added in v0.3.8
func (x *BlockHistory) ClearProtocol()
func (*BlockHistory) ClearTime ¶ added in v0.3.8
func (x *BlockHistory) ClearTime()
func (*BlockHistory) GetBlockCount ¶ added in v0.3.8
func (x *BlockHistory) GetBlockCount() uint64
func (*BlockHistory) GetHost ¶ added in v0.3.7
func (x *BlockHistory) GetHost() string
func (*BlockHistory) GetProcess ¶ added in v0.3.7
func (x *BlockHistory) GetProcess() string
func (*BlockHistory) GetProtocol ¶ added in v0.3.7
func (x *BlockHistory) GetProtocol() string
func (*BlockHistory) GetTime ¶ added in v0.3.7
func (x *BlockHistory) GetTime() *timestamppb.Timestamp
func (*BlockHistory) HasBlockCount ¶ added in v0.3.8
func (x *BlockHistory) HasBlockCount() bool
func (*BlockHistory) HasHost ¶ added in v0.3.8
func (x *BlockHistory) HasHost() bool
func (*BlockHistory) HasProcess ¶ added in v0.3.8
func (x *BlockHistory) HasProcess() bool
func (*BlockHistory) HasProtocol ¶ added in v0.3.8
func (x *BlockHistory) HasProtocol() bool
func (*BlockHistory) HasTime ¶ added in v0.3.8
func (x *BlockHistory) HasTime() bool
func (*BlockHistory) ProtoMessage ¶ added in v0.3.7
func (*BlockHistory) ProtoMessage()
func (*BlockHistory) ProtoReflect ¶ added in v0.3.7
func (x *BlockHistory) ProtoReflect() protoreflect.Message
func (*BlockHistory) Reset ¶ added in v0.3.7
func (x *BlockHistory) Reset()
func (*BlockHistory) SetBlockCount ¶ added in v0.3.8
func (x *BlockHistory) SetBlockCount(v uint64)
func (*BlockHistory) SetHost ¶ added in v0.3.8
func (x *BlockHistory) SetHost(v string)
func (*BlockHistory) SetProcess ¶ added in v0.3.8
func (x *BlockHistory) SetProcess(v string)
func (*BlockHistory) SetProtocol ¶ added in v0.3.8
func (x *BlockHistory) SetProtocol(v string)
func (*BlockHistory) SetTime ¶ added in v0.3.8
func (x *BlockHistory) SetTime(v *timestamppb.Timestamp)
func (*BlockHistory) String ¶ added in v0.3.7
func (x *BlockHistory) String() string
type BlockHistoryList ¶ added in v0.3.7
type BlockHistoryList struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*BlockHistoryList) ClearDumpProcessEnabled ¶ added in v0.3.8
func (x *BlockHistoryList) ClearDumpProcessEnabled()
func (*BlockHistoryList) GetDumpProcessEnabled ¶ added in v0.3.7
func (x *BlockHistoryList) GetDumpProcessEnabled() bool
func (*BlockHistoryList) GetObjects ¶ added in v0.3.7
func (x *BlockHistoryList) GetObjects() []*BlockHistory
func (*BlockHistoryList) HasDumpProcessEnabled ¶ added in v0.3.8
func (x *BlockHistoryList) HasDumpProcessEnabled() bool
func (*BlockHistoryList) ProtoMessage ¶ added in v0.3.7
func (*BlockHistoryList) ProtoMessage()
func (*BlockHistoryList) ProtoReflect ¶ added in v0.3.7
func (x *BlockHistoryList) ProtoReflect() protoreflect.Message
func (*BlockHistoryList) Reset ¶ added in v0.3.7
func (x *BlockHistoryList) Reset()
func (*BlockHistoryList) SetDumpProcessEnabled ¶ added in v0.3.8
func (x *BlockHistoryList) SetDumpProcessEnabled(v bool)
func (*BlockHistoryList) SetObjects ¶ added in v0.3.8
func (x *BlockHistoryList) SetObjects(v []*BlockHistory)
func (*BlockHistoryList) String ¶ added in v0.3.7
func (x *BlockHistoryList) String() string
type BlockHistoryList_builder ¶ added in v0.3.8
type BlockHistoryList_builder struct {
Objects []*BlockHistory
DumpProcessEnabled *bool
// contains filtered or unexported fields
}
func (BlockHistoryList_builder) Build ¶ added in v0.3.8
func (b0 BlockHistoryList_builder) Build() *BlockHistoryList
type BlockHistory_builder ¶ added in v0.3.8
type BlockHistory_builder struct {
Protocol *string
Host *string
Time *timestamppb.Timestamp
Process *string
BlockCount *uint64
// contains filtered or unexported fields
}
func (BlockHistory_builder) Build ¶ added in v0.3.8
func (b0 BlockHistory_builder) Build() *BlockHistory
type BypassClient ¶ added in v0.3.7
type BypassClient interface {
Load(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*bypass.Config, error)
Save(ctx context.Context, in *bypass.Config, opts ...grpc.CallOption) (*emptypb.Empty, error)
Reload(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*emptypb.Empty, error)
Test(ctx context.Context, in *wrapperspb.StringValue, opts ...grpc.CallOption) (*TestResponse, error)
BlockHistory(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*BlockHistoryList, error)
}
BypassClient is the client API for Bypass service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBypassClient ¶ added in v0.3.7
func NewBypassClient(cc grpc.ClientConnInterface) BypassClient
type BypassServer ¶ added in v0.3.7
type BypassServer interface {
Load(context.Context, *emptypb.Empty) (*bypass.Config, error)
Save(context.Context, *bypass.Config) (*emptypb.Empty, error)
Reload(context.Context, *emptypb.Empty) (*emptypb.Empty, error)
Test(context.Context, *wrapperspb.StringValue) (*TestResponse, error)
BlockHistory(context.Context, *emptypb.Empty) (*BlockHistoryList, error)
// contains filtered or unexported methods
}
BypassServer is the server API for Bypass service. All implementations must embed UnimplementedBypassServer for forward compatibility.
type ConfigServiceClient ¶
type ConfigServiceClient interface {
Load(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*config.Setting, error)
Save(ctx context.Context, in *config.Setting, opts ...grpc.CallOption) (*emptypb.Empty, error)
Info(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*config.Info, error)
}
ConfigServiceClient is the client API for ConfigService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewConfigServiceClient ¶
func NewConfigServiceClient(cc grpc.ClientConnInterface) ConfigServiceClient
type ConfigServiceServer ¶
type ConfigServiceServer interface {
Load(context.Context, *emptypb.Empty) (*config.Setting, error)
Save(context.Context, *config.Setting) (*emptypb.Empty, error)
Info(context.Context, *emptypb.Empty) (*config.Info, error)
// contains filtered or unexported methods
}
ConfigServiceServer is the server API for ConfigService service. All implementations must embed UnimplementedConfigServiceServer for forward compatibility.
type Hosts ¶ added in v0.3.8
type Hosts struct {
// contains filtered or unexported fields
}
func (*Hosts) ProtoMessage ¶ added in v0.3.8
func (*Hosts) ProtoMessage()
func (*Hosts) ProtoReflect ¶ added in v0.3.8
func (x *Hosts) ProtoReflect() protoreflect.Message
type Hosts_builder ¶ added in v0.3.8
func (Hosts_builder) Build ¶ added in v0.3.8
func (b0 Hosts_builder) Build() *Hosts
type InboundClient ¶ added in v0.3.8
type InboundClient interface {
List(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*InboundsResponse, error)
Get(ctx context.Context, in *wrapperspb.StringValue, opts ...grpc.CallOption) (*listener.Inbound, error)
Save(ctx context.Context, in *listener.Inbound, opts ...grpc.CallOption) (*listener.Inbound, error)
Remove(ctx context.Context, in *wrapperspb.StringValue, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
InboundClient is the client API for Inbound service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewInboundClient ¶ added in v0.3.8
func NewInboundClient(cc grpc.ClientConnInterface) InboundClient
type InboundServer ¶ added in v0.3.8
type InboundServer interface {
List(context.Context, *emptypb.Empty) (*InboundsResponse, error)
Get(context.Context, *wrapperspb.StringValue) (*listener.Inbound, error)
Save(context.Context, *listener.Inbound) (*listener.Inbound, error)
Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
InboundServer is the server API for Inbound service. All implementations must embed UnimplementedInboundServer for forward compatibility.
type InboundsResponse ¶ added in v0.3.8
type InboundsResponse struct {
// contains filtered or unexported fields
}
func (*InboundsResponse) GetNames ¶ added in v0.3.8
func (x *InboundsResponse) GetNames() []string
func (*InboundsResponse) ProtoMessage ¶ added in v0.3.8
func (*InboundsResponse) ProtoMessage()
func (*InboundsResponse) ProtoReflect ¶ added in v0.3.8
func (x *InboundsResponse) ProtoReflect() protoreflect.Message
func (*InboundsResponse) Reset ¶ added in v0.3.8
func (x *InboundsResponse) Reset()
func (*InboundsResponse) SetNames ¶ added in v0.3.8
func (x *InboundsResponse) SetNames(v []string)
func (*InboundsResponse) String ¶ added in v0.3.8
func (x *InboundsResponse) String() string
type InboundsResponse_builder ¶ added in v0.3.8
type InboundsResponse_builder struct {
Names []string
// contains filtered or unexported fields
}
func (InboundsResponse_builder) Build ¶ added in v0.3.8
func (b0 InboundsResponse_builder) Build() *InboundsResponse
type ResolveList ¶ added in v0.3.8
type ResolveList struct {
// contains filtered or unexported fields
}
func (*ResolveList) GetNames ¶ added in v0.3.8
func (x *ResolveList) GetNames() []string
func (*ResolveList) ProtoMessage ¶ added in v0.3.8
func (*ResolveList) ProtoMessage()
func (*ResolveList) ProtoReflect ¶ added in v0.3.8
func (x *ResolveList) ProtoReflect() protoreflect.Message
func (*ResolveList) Reset ¶ added in v0.3.8
func (x *ResolveList) Reset()
func (*ResolveList) SetNames ¶ added in v0.3.8
func (x *ResolveList) SetNames(v []string)
func (*ResolveList) String ¶ added in v0.3.8
func (x *ResolveList) String() string
type ResolveList_builder ¶ added in v0.3.8
type ResolveList_builder struct {
Names []string
// contains filtered or unexported fields
}
func (ResolveList_builder) Build ¶ added in v0.3.8
func (b0 ResolveList_builder) Build() *ResolveList
type ResolverClient ¶ added in v0.3.8
type ResolverClient interface {
List(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*ResolveList, error)
Get(ctx context.Context, in *wrapperspb.StringValue, opts ...grpc.CallOption) (*dns.Dns, error)
Save(ctx context.Context, in *SaveResolver, opts ...grpc.CallOption) (*dns.Dns, error)
// the bootstrap can't be remove
Remove(ctx context.Context, in *wrapperspb.StringValue, opts ...grpc.CallOption) (*emptypb.Empty, error)
Hosts(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Hosts, error)
SaveHosts(ctx context.Context, in *Hosts, opts ...grpc.CallOption) (*emptypb.Empty, error)
Fakedns(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*dns.FakednsConfig, error)
SaveFakedns(ctx context.Context, in *dns.FakednsConfig, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
ResolverClient is the client API for Resolver service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewResolverClient ¶ added in v0.3.8
func NewResolverClient(cc grpc.ClientConnInterface) ResolverClient
type ResolverServer ¶ added in v0.3.8
type ResolverServer interface {
List(context.Context, *emptypb.Empty) (*ResolveList, error)
Get(context.Context, *wrapperspb.StringValue) (*dns.Dns, error)
Save(context.Context, *SaveResolver) (*dns.Dns, error)
// the bootstrap can't be remove
Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
Hosts(context.Context, *emptypb.Empty) (*Hosts, error)
SaveHosts(context.Context, *Hosts) (*emptypb.Empty, error)
Fakedns(context.Context, *emptypb.Empty) (*dns.FakednsConfig, error)
SaveFakedns(context.Context, *dns.FakednsConfig) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
ResolverServer is the server API for Resolver service. All implementations must embed UnimplementedResolverServer for forward compatibility.
type SaveResolver ¶ added in v0.3.8
type SaveResolver struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*SaveResolver) ClearName ¶ added in v0.3.8
func (x *SaveResolver) ClearName()
func (*SaveResolver) ClearResolver ¶ added in v0.3.8
func (x *SaveResolver) ClearResolver()
func (*SaveResolver) GetName ¶ added in v0.3.8
func (x *SaveResolver) GetName() string
func (*SaveResolver) GetResolver ¶ added in v0.3.8
func (x *SaveResolver) GetResolver() *dns.Dns
func (*SaveResolver) HasName ¶ added in v0.3.8
func (x *SaveResolver) HasName() bool
func (*SaveResolver) HasResolver ¶ added in v0.3.8
func (x *SaveResolver) HasResolver() bool
func (*SaveResolver) ProtoMessage ¶ added in v0.3.8
func (*SaveResolver) ProtoMessage()
func (*SaveResolver) ProtoReflect ¶ added in v0.3.8
func (x *SaveResolver) ProtoReflect() protoreflect.Message
func (*SaveResolver) Reset ¶ added in v0.3.8
func (x *SaveResolver) Reset()
func (*SaveResolver) SetName ¶ added in v0.3.8
func (x *SaveResolver) SetName(v string)
func (*SaveResolver) SetResolver ¶ added in v0.3.8
func (x *SaveResolver) SetResolver(v *dns.Dns)
func (*SaveResolver) String ¶ added in v0.3.8
func (x *SaveResolver) String() string
type SaveResolver_builder ¶ added in v0.3.8
type SaveResolver_builder struct {
Name *string
Resolver *dns.Dns
// contains filtered or unexported fields
}
func (SaveResolver_builder) Build ¶ added in v0.3.8
func (b0 SaveResolver_builder) Build() *SaveResolver
type TestResponse ¶ added in v0.3.7
type TestResponse struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*TestResponse) ClearAfterAddr ¶ added in v0.3.8
func (x *TestResponse) ClearAfterAddr()
func (*TestResponse) ClearMode ¶ added in v0.3.8
func (x *TestResponse) ClearMode()
func (*TestResponse) ClearReason ¶ added in v0.3.8
func (x *TestResponse) ClearReason()
func (*TestResponse) GetAfterAddr ¶ added in v0.3.7
func (x *TestResponse) GetAfterAddr() string
func (*TestResponse) GetMode ¶ added in v0.3.7
func (x *TestResponse) GetMode() *bypass.ModeConfig
func (*TestResponse) GetReason ¶ added in v0.3.7
func (x *TestResponse) GetReason() string
func (*TestResponse) HasAfterAddr ¶ added in v0.3.8
func (x *TestResponse) HasAfterAddr() bool
func (*TestResponse) HasMode ¶ added in v0.3.8
func (x *TestResponse) HasMode() bool
func (*TestResponse) HasReason ¶ added in v0.3.8
func (x *TestResponse) HasReason() bool
func (*TestResponse) ProtoMessage ¶ added in v0.3.7
func (*TestResponse) ProtoMessage()
func (*TestResponse) ProtoReflect ¶ added in v0.3.7
func (x *TestResponse) ProtoReflect() protoreflect.Message
func (*TestResponse) Reset ¶ added in v0.3.7
func (x *TestResponse) Reset()
func (*TestResponse) SetAfterAddr ¶ added in v0.3.8
func (x *TestResponse) SetAfterAddr(v string)
func (*TestResponse) SetMode ¶ added in v0.3.8
func (x *TestResponse) SetMode(v *bypass.ModeConfig)
func (*TestResponse) SetReason ¶ added in v0.3.8
func (x *TestResponse) SetReason(v string)
func (*TestResponse) String ¶ added in v0.3.7
func (x *TestResponse) String() string
type TestResponse_builder ¶ added in v0.3.8
type TestResponse_builder struct {
Mode *bypass.ModeConfig
Reason *string
AfterAddr *string
// contains filtered or unexported fields
}
func (TestResponse_builder) Build ¶ added in v0.3.8
func (b0 TestResponse_builder) Build() *TestResponse
type UnimplementedBypassServer ¶ added in v0.3.7
type UnimplementedBypassServer struct{}
UnimplementedBypassServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedBypassServer) BlockHistory ¶ added in v0.3.7
func (UnimplementedBypassServer) BlockHistory(context.Context, *emptypb.Empty) (*BlockHistoryList, error)
func (UnimplementedBypassServer) Test ¶ added in v0.3.7
func (UnimplementedBypassServer) Test(context.Context, *wrapperspb.StringValue) (*TestResponse, error)
type UnimplementedConfigServiceServer ¶
type UnimplementedConfigServiceServer struct{}
UnimplementedConfigServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
type UnimplementedInboundServer ¶ added in v0.3.8
type UnimplementedInboundServer struct{}
UnimplementedInboundServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedInboundServer) Get ¶ added in v0.3.8
func (UnimplementedInboundServer) Get(context.Context, *wrapperspb.StringValue) (*listener.Inbound, error)
func (UnimplementedInboundServer) List ¶ added in v0.3.8
func (UnimplementedInboundServer) List(context.Context, *emptypb.Empty) (*InboundsResponse, error)
func (UnimplementedInboundServer) Remove ¶ added in v0.3.8
func (UnimplementedInboundServer) Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
type UnimplementedResolverServer ¶ added in v0.3.8
type UnimplementedResolverServer struct{}
UnimplementedResolverServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedResolverServer) Fakedns ¶ added in v0.3.8
func (UnimplementedResolverServer) Fakedns(context.Context, *emptypb.Empty) (*dns.FakednsConfig, error)
func (UnimplementedResolverServer) Get ¶ added in v0.3.8
func (UnimplementedResolverServer) Get(context.Context, *wrapperspb.StringValue) (*dns.Dns, error)
func (UnimplementedResolverServer) List ¶ added in v0.3.8
func (UnimplementedResolverServer) List(context.Context, *emptypb.Empty) (*ResolveList, error)
func (UnimplementedResolverServer) Remove ¶ added in v0.3.8
func (UnimplementedResolverServer) Remove(context.Context, *wrapperspb.StringValue) (*emptypb.Empty, error)
func (UnimplementedResolverServer) Save ¶ added in v0.3.8
func (UnimplementedResolverServer) Save(context.Context, *SaveResolver) (*dns.Dns, error)
func (UnimplementedResolverServer) SaveFakedns ¶ added in v0.3.8
func (UnimplementedResolverServer) SaveFakedns(context.Context, *dns.FakednsConfig) (*emptypb.Empty, error)
type UnsafeBypassServer ¶ added in v0.3.7
type UnsafeBypassServer interface {
// contains filtered or unexported methods
}
UnsafeBypassServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BypassServer will result in compilation errors.
type UnsafeConfigServiceServer ¶
type UnsafeConfigServiceServer interface {
// contains filtered or unexported methods
}
UnsafeConfigServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConfigServiceServer will result in compilation errors.
type UnsafeInboundServer ¶ added in v0.3.8
type UnsafeInboundServer interface {
// contains filtered or unexported methods
}
UnsafeInboundServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to InboundServer will result in compilation errors.
type UnsafeResolverServer ¶ added in v0.3.8
type UnsafeResolverServer interface {
// contains filtered or unexported methods
}
UnsafeResolverServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ResolverServer will result in compilation errors.