Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterToolsServer(s grpc.ServiceRegistrar, srv ToolsServer)
- type Interface
- func (x *Interface) ClearName()
- func (x *Interface) GetAddresses() []string
- func (x *Interface) GetName() string
- func (x *Interface) HasName() bool
- func (*Interface) ProtoMessage()
- func (x *Interface) ProtoReflect() protoreflect.Message
- func (x *Interface) Reset()
- func (x *Interface) SetAddresses(v []string)
- func (x *Interface) SetName(v string)
- func (x *Interface) String() string
- type Interface_builder
- type Interfaces
- type Interfaces_builder
- type Tools
- type ToolsClient
- type ToolsServer
- type UnimplementedToolsServer
- type UnsafeToolsServer
Constants ¶
const (
Tools_GetInterface_FullMethodName = "/yuhaiin.tools.tools/get_interface"
)
Variables ¶
var File_tools_tools_proto protoreflect.FileDescriptor
var Tools_ServiceDesc = grpc.ServiceDesc{ ServiceName: "yuhaiin.tools.tools", HandlerType: (*ToolsServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "get_interface", Handler: _Tools_GetInterface_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "tools/tools.proto", }
Tools_ServiceDesc is the grpc.ServiceDesc for Tools service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterToolsServer ¶
func RegisterToolsServer(s grpc.ServiceRegistrar, srv ToolsServer)
Types ¶
type Interface ¶ added in v0.3.4
type Interface struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*Interface) GetAddresses ¶ added in v0.3.4
func (*Interface) ProtoMessage ¶ added in v0.3.4
func (*Interface) ProtoMessage()
func (*Interface) ProtoReflect ¶ added in v0.3.4
func (x *Interface) ProtoReflect() protoreflect.Message
func (*Interface) SetAddresses ¶ added in v0.3.8
type Interface_builder ¶ added in v0.3.8
type Interface_builder struct {
Name *string
Addresses []string
// contains filtered or unexported fields
}
func (Interface_builder) Build ¶ added in v0.3.8
func (b0 Interface_builder) Build() *Interface
type Interfaces ¶ added in v0.3.4
type Interfaces struct {
// contains filtered or unexported fields
}
func (*Interfaces) GetInterfaces ¶ added in v0.3.4
func (x *Interfaces) GetInterfaces() []*Interface
func (*Interfaces) ProtoMessage ¶ added in v0.3.4
func (*Interfaces) ProtoMessage()
func (*Interfaces) ProtoReflect ¶ added in v0.3.4
func (x *Interfaces) ProtoReflect() protoreflect.Message
func (*Interfaces) Reset ¶ added in v0.3.4
func (x *Interfaces) Reset()
func (*Interfaces) SetInterfaces ¶ added in v0.3.8
func (x *Interfaces) SetInterfaces(v []*Interface)
func (*Interfaces) String ¶ added in v0.3.4
func (x *Interfaces) String() string
type Interfaces_builder ¶ added in v0.3.8
type Interfaces_builder struct {
Interfaces []*Interface
// contains filtered or unexported fields
}
func (Interfaces_builder) Build ¶ added in v0.3.8
func (b0 Interfaces_builder) Build() *Interfaces
type Tools ¶ added in v0.3.6
type Tools struct {
UnimplementedToolsServer
// contains filtered or unexported fields
}
func (*Tools) GetInterface ¶ added in v0.3.6
type ToolsClient ¶
type ToolsClient interface {
GetInterface(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Interfaces, error)
}
ToolsClient is the client API for Tools service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewToolsClient ¶
func NewToolsClient(cc grpc.ClientConnInterface) ToolsClient
type ToolsServer ¶
type ToolsServer interface {
GetInterface(context.Context, *emptypb.Empty) (*Interfaces, error)
// contains filtered or unexported methods
}
ToolsServer is the server API for Tools service. All implementations must embed UnimplementedToolsServer for forward compatibility.
type UnimplementedToolsServer ¶
type UnimplementedToolsServer struct{}
UnimplementedToolsServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedToolsServer) GetInterface ¶ added in v0.3.4
func (UnimplementedToolsServer) GetInterface(context.Context, *emptypb.Empty) (*Interfaces, error)
type UnsafeToolsServer ¶
type UnsafeToolsServer interface {
// contains filtered or unexported methods
}
UnsafeToolsServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ToolsServer will result in compilation errors.